@@ -23,6 +23,14 @@
 
 #include "core/operationstack.h"
 #include "core/device.h"
+#include "core/lvmdevice.h"
+#include "core/diskdevice.h"
+
+#include "fs/lvm2_pv.h"
+
+#include "util/externalcommand.h"
+
+#include <QRegularExpression>
 
 /** Constructs a DeviceScanner
     @param ostack the OperationStack where the devices will be created
@@ -56,10 +64,24 @@ void DeviceScanner::scan()
 
     clear();
 
-    QList<Device*> deviceList = CoreBackendManager::self()->backend()->scanDevices();
+    const QList<Device*> deviceList = CoreBackendManager::self()->backend()->scanDevices();
+    const QList<LvmDevice*> lvmList = LvmDevice::scanSystemLVM();
+    LVM::pvList = FS::lvm2_pv::getPVs(deviceList);
 
-    foreach(Device * d, deviceList)
+    for (const auto &d : deviceList)
         operationStack().addDevice(d);
 
     operationStack().sortDevices();
+
+    for (const auto &d : lvmList) {
+        operationStack().addDevice(d);
+        LVM::pvList.append(FS::lvm2_pv::getPVinNode(d->partitionTable()));
+    }
+
+    // Store list of physical volumes in LvmDevice
+    for (const auto &d : lvmList)
+        for (const auto &p : LVM::pvList) // FIXME: qAsConst
+            if (p.vgName() == d->name())
+                d->physicalVolumes().append(p.partition());
 }
+
