@@ -51,20 +51,20 @@ QString SmartAttribute::assessmentToString(Assessment a)
 {
     switch (a) {
     case Failing:
-        return i18nc("@item:intable", "failing");
+        return xi18nc("@item:intable", "failing");
 
     case HasFailed:
-        return i18nc("@item:intable", "has failed");
+        return xi18nc("@item:intable", "has failed");
 
     case Warning:
-        return i18nc("@item:intable", "warning");
+        return xi18nc("@item:intable", "warning");
 
     case Good:
-        return i18nc("@item:intable", "good");
+        return xi18nc("@item:intable", "good");
 
     case NotApplicable:
     default:
-        return i18nc("@item:intable not applicable", "N/A");
+        return xi18nc("@item:intable not applicable", "N/A");
     }
 }
 
@@ -78,7 +78,7 @@ static QString getPrettyValue(qint64 value, qint64 unit)
         break;
 
     case SK_SMART_ATTRIBUTE_UNIT_SECTORS:
-        rval = i18ncp("@item:intable", "%1 sector", "%1 sectors", value);
+        rval = xi18ncp("@item:intable", "%1 sector", "%1 sectors", value);
         break;
 
     case SK_SMART_ATTRIBUTE_UNIT_MKELVIN:
@@ -91,7 +91,7 @@ static QString getPrettyValue(qint64 value, qint64 unit)
 
     case SK_SMART_ATTRIBUTE_UNIT_UNKNOWN:
     default:
-        rval = i18nc("@item:intable not applicable", "N/A");
+        rval = xi18nc("@item:intable not applicable", "N/A");
         break;
     }
 
@@ -120,6 +120,18 @@ static const AttrDetails* attrDetails()
         { 11,  i18nc("SMART attr name", "Recalibration Retries"), i18nc("SMART attr description", "Count of recalibrations requested if the first attempt was unsuccessful. An increase of this attribute value is a sign of problems in the hard disk mechanical subsystem.")  },
         { 12,  i18nc("SMART attr name", "Power Cycle Count"), i18nc("SMART attr description", "Count of full hard disk power on/off cycles.")  },
         { 13,  i18nc("SMART attr name", "Soft Read Error Rate"), i18nc("SMART attr description", "Uncorrected read errors reported to the operating system.")  },
+        { 170,  i18nc("SMART attr name", "SSD Available Reserved Space"), i18nc("SMART attr description", "Number of available reserved space as a percentage of reserved space.")  },
+        { 171,  i18nc("SMART attr name", "SSD Program Fail Count"), i18nc("SMART attr description", "Number of flash program operation failures since the drive was deployed.") },
+        { 172,  i18nc("SMART attr name", "SSD Erase Fail Count"), i18nc("SMART attr description", "Number of flash erase operation failures since the drive was deployed.") },
+        { 173,  i18nc("SMART attr name", "SSD Wear Leveling Count"), i18nc("SMART attr description", "Counts the maximum worst erase count on any block.") },
+        { 174,  i18nc("SMART attr name", "SSD Unexpected power loss count"), i18nc("SMART attr description", "Number of shutdowns without STANDBY IMMEDIATE as the last command (regardless of PLI activity using capacitor power). Normalized value is always 100.") },
+        { 175,  i18nc("SMART attr name", "SSD Power Loss Protection Failure"), i18nc("SMART attr description", "Last test result, saturated at its maximum value. Bytes 0-1: last test result as microseconds to discharge cap in range [25, 5000000], lower indicates specific error code. Bytes 2-3: minutes since last test. Bytes 4-5: lifetime number of tests. Normalized value is set to 1 on test failure or 11 if the capacitor has been tested in an excessive temperature condition, otherwise 100.") },
+        { 176,  i18nc("SMART attr name", "SSD Erase Fail Count (chip)"), i18nc("SMART attr description", "Number of flash erase command failures.") },
+        { 177,  i18nc("SMART attr name", "SSD Wear Range Delta"), i18nc("SMART attr description", "Delta between most-worn and least-worn flash blocks.") },
+        { 179,  i18nc("SMART attr name", "SSD Used Reserved Block Count Total"), i18nc("SMART attr description", "\"Pre-Fail\" Samsung attribute.") },
+        { 180,  i18nc("SMART attr name", "SSD Unused Reserved Block Count Total"), i18nc("SMART attr description", "\"Pre-Fail\" HP attribute.") },
+        { 181,  i18nc("SMART attr name", "SSD Program Fail Count Total or Non-4K Aligned Access Count"), i18nc("SMART attr description", "Number of flash program operation failures since the drive was deployed.") },
+        { 182,  i18nc("SMART attr name", "SSD Erase Fail Count"), i18nc("SMART attr description", "\"Pre-Fail\" Samsung attribute.") },
         { 183,  i18nc("SMART attr name", "SATA Downshift Error Count"), i18nc("SMART attr description", "Western Digital and Samsung attribute.")  },
         { 184,  i18nc("SMART attr name", "End-to-End Error"), i18nc("SMART attr description", "Part of HP's SMART IV technology: After transferring through the cache RAM data buffer the parity data between the host and the hard drive did not match.")  },
         { 185,  i18nc("SMART attr name", "Head Stability"), i18nc("SMART attr description", "Western Digital attribute.")  },
@@ -167,6 +179,7 @@ static const AttrDetails* attrDetails()
         { 240,  i18nc("SMART attr name", "Head Flying Hours<br/>or Transfer Error Rate (Fujitsu)"), i18nc("SMART attr description", "Time while head is positioning<br/>or counts the number of times the link is reset during a data transfer.")  },
         { 241,  i18nc("SMART attr name", "Total LBAs Written"), i18nc("SMART attr description", "Total LBAs Written")  },
         { 242,  i18nc("SMART attr name", "Total LBAs Read"), i18nc("SMART attr description", "Total LBAs Read")  },
+        { 249,  i18nc("SMART attr name", "SSD NAND_Writes_1GiB"), i18nc("SMART attr description", "Number of writes to NAND in 1 GB increments")  },
         { 250,  i18nc("SMART attr name", "Read Error Retry Rate"), i18nc("SMART attr description", "Number of errors while reading from a disk")  },
         { 254,  i18nc("SMART attr name", "Free Fall Protection"), i18nc("SMART attr description", "Number of &quot;Free Fall Events&quot; detected") },
         { -1, QString(), QString() }
