@@ -62,6 +62,8 @@ luks::luks(qint64 firstsector,
     , m_isCryptOpen(false)
     , m_cryptsetupFound(m_Create != cmdSupportNone)
     , m_isMounted(false)
+    , m_KeySize(-1)
+    , m_PayloadOffset(-1)
 {
 }
 
@@ -503,19 +505,38 @@ bool luks::resize(Report& report, const QString& deviceNode, qint64 newLength) c
     return false;
 }
 
+bool luks::resizeOnline(Report& report, const QString& deviceNode, const QString& mountPoint, qint64 length) const
+{
+    Q_UNUSED(mountPoint)
+    return resize(report, deviceNode, length);
+}
+
 QString luks::readUUID(const QString& deviceNode) const
 {
+    QString outerUuid = readOuterUUID(deviceNode);
     if (m_isCryptOpen && m_innerFs)
         return m_innerFs->readUUID(mapperName());
-    return readOuterUUID(deviceNode);
+    return outerUuid;
 }
 
 QString luks::readOuterUUID(const QString &deviceNode) const
 {
+    if ( deviceNode.isEmpty() )
+        return QString();
+
     ExternalCommand cmd(QStringLiteral("cryptsetup"),
                         { QStringLiteral("luksUUID"), deviceNode });
     if (cmd.run()) {
-        return cmd.output().trimmed();
+        if ( cmd.exitCode() )
+        {
+            qWarning() << "Cannot get luksUUID for device" << deviceNode
+                       << "\tcryptsetup exit code" << cmd.exitCode()
+                       << "\toutput:" << cmd.output().trimmed();
+            return QString();
+        }
+        QString outerUuid = cmd.output().trimmed();
+        const_cast< QString& >( m_outerUuid ) = outerUuid;
+        return outerUuid;
     }
     return QStringLiteral("---");
 }
@@ -601,6 +622,11 @@ void luks::getLuksInfo(const QString& deviceNode)
     }
 }
 
+QString luks::outerUuid() const
+{
+    return m_outerUuid;
+}
+
 bool luks::canEncryptType(FileSystem::Type type)
 {
     switch (type)
@@ -624,17 +650,14 @@ bool luks::canEncryptType(FileSystem::Type type)
     }
 }
 
-void luks::initLUKS(FileSystem* fs)
+void luks::initLUKS()
 {
-    if (fs->type() == FileSystem::Luks) {
-        FS::luks* luksFS = static_cast<FS::luks*>(fs);
-        QString mapperNode = luksFS->mapperName();
-        bool isCryptOpen = !mapperNode.isEmpty();
-        luksFS->setCryptOpen(isCryptOpen);
-        if (isCryptOpen) {
-            luksFS->loadInnerFileSystem(mapperNode);
-            luksFS->setMounted(detectMountStatus(luksFS->innerFS(), mapperNode));
-        }
+    QString mapperNode = mapperName();
+    bool isCryptOpen = !mapperNode.isEmpty();
+    setCryptOpen(isCryptOpen);
+    if (isCryptOpen) {
+        loadInnerFileSystem(mapperNode);
+        setMounted(detectMountStatus(innerFS(), mapperNode));
     }
 }
 
