@@ -41,8 +41,12 @@ FileSystem::CommandSupportType lvm2_pv::m_SetLabel = FileSystem::cmdSupportNone;
 FileSystem::CommandSupportType lvm2_pv::m_UpdateUUID = FileSystem::cmdSupportNone;
 FileSystem::CommandSupportType lvm2_pv::m_GetUUID = FileSystem::cmdSupportNone;
 
-lvm2_pv::lvm2_pv(qint64 firstsector, qint64 lastsector, qint64 sectorsused, const QString& label) :
-    FileSystem(firstsector, lastsector, sectorsused, label, FileSystem::Lvm2_PV)
+lvm2_pv::lvm2_pv(qint64 firstsector, qint64 lastsector,
+                 qint64 sectorsused, const QString& label)
+    : FileSystem(firstsector, lastsector, sectorsused, label, FileSystem::Lvm2_PV)
+    , m_PESize(0)
+    , m_TotalPE(0)
+    , m_AllocatedPE(0)
 {
 }
 
