@@ -31,7 +31,7 @@
 #include <QPaintEvent>
 #include <QResizeEvent>
 #include <QStyleOptionToolBar>
-#include <QStyleOptionFrameV3>
+#include <QStyleOptionFrame>
 #include <QStyleOptionButton>
 
 const qint32 PartResizerWidget::m_HandleHeight = 59;
@@ -133,9 +133,9 @@ qint32 PartResizerWidget::handleWidth() const
     return style()->pixelMetric(QStyle::PM_SplitterWidth);
 }
 
-qint64 PartResizerWidget::sectorsPerPixel() const
+long double PartResizerWidget::sectorsPerPixel() const
 {
-    return totalSectors() / (width() - 2 * handleWidth());
+    return totalSectors() / (width() - 2.0L * handleWidth());
 }
 
 int PartResizerWidget::partWidgetStart() const
@@ -172,7 +172,7 @@ void PartResizerWidget::paintEvent(QPaintEvent*)
 {
     // draw sunken frame
     QPainter painter(this);
-    QStyleOptionFrameV3 opt;
+    QStyleOptionFrame opt;
     opt.initFrom(this);
     opt.frameShape = QFrame::StyledPanel;
     opt.rect = contentsRect();
@@ -285,13 +285,13 @@ void PartResizerWidget::mouseMoveEvent(QMouseEvent* event)
     int x = event->pos().x() - m_Hotspot;
 
     if (draggedWidget() == &leftHandle()) {
-        const qint64 newFirstSector = qMax(minimumFirstSector() + x * sectorsPerPixel(), 0LL);
+        const qint64 newFirstSector = qMax(minimumFirstSector() + x * sectorsPerPixel(), 0.0L);
         updateFirstSector(newFirstSector);
     } else if (draggedWidget() == &rightHandle()) {
-        const qint64 newLastSector = qMin(minimumFirstSector() + (x - rightHandle().width()) * sectorsPerPixel(), maximumLastSector());
+        const qint64 newLastSector = qMin(static_cast<qint64>(minimumFirstSector() + (x - rightHandle().width()) * sectorsPerPixel()), maximumLastSector());
         updateLastSector(newLastSector);
     } else if (draggedWidget() == &partWidget() && moveAllowed()) {
-        const qint64 newFirstSector = qMax(minimumFirstSector() + (x - handleWidth()) * sectorsPerPixel(), 0LL);
+        const qint64 newFirstSector = qMax(minimumFirstSector() + (x - handleWidth()) * sectorsPerPixel(), 0.0L);
         movePartition(newFirstSector);
     }
 }
