@@ -25,6 +25,7 @@
 
 #include "core/partition.h"
 #include "core/device.h"
+#include "core/lvmdevice.h"
 
 #include "util/report.h"
 
@@ -49,29 +50,38 @@ bool CreatePartitionJob::run(Report& parent)
 
     Report* report = jobStarted(parent);
 
-    CoreBackendDevice* backendDevice = CoreBackendManager::self()->backend()->openDevice(device().deviceNode());
+    if (device().type() == Device::Disk_Device) {
+        CoreBackendDevice* backendDevice = CoreBackendManager::self()->backend()->openDevice(device().deviceNode());
 
-    if (backendDevice) {
-        CoreBackendPartitionTable* backendPartitionTable = backendDevice->openPartitionTable();
+        if (backendDevice) {
+            CoreBackendPartitionTable* backendPartitionTable = backendDevice->openPartitionTable();
 
-        if (backendPartitionTable) {
-            QString partitionPath = backendPartitionTable->createPartition(*report, partition());
+            if (backendPartitionTable) {
+                QString partitionPath = backendPartitionTable->createPartition(*report, partition());
 
-            if (partitionPath != QString()) {
-                rval = true;
-                partition().setPartitionPath(partitionPath);
-                partition().setState(Partition::StateNone);
-                backendPartitionTable->commit();
+                if (partitionPath != QString()) {
+                    rval = true;
+                    partition().setPartitionPath(partitionPath);
+                    partition().setState(Partition::StateNone);
+                    backendPartitionTable->commit();
+                } else
+                    report->line() << xi18nc("@info/plain", "Failed to add partition <filename>%1</filename> to device <filename>%2</filename>.", partition().deviceNode(), device().deviceNode());
+
+                delete backendPartitionTable;
             } else
-                report->line() << xi18nc("@info/plain", "Failed to add partition <filename>%1</filename> to device <filename>%2</filename>.", partition().deviceNode(), device().deviceNode());
+                report->line() << xi18nc("@info:progress", "Could not open partition table on device <filename>%1</filename> to create new partition <filename>%2</filename>.", device().deviceNode(), partition().deviceNode());
 
-            delete backendPartitionTable;
+            delete backendDevice;
         } else
-            report->line() << xi18nc("@info/plain", "Could not open partition table on device <filename>%1</filename> to create new partition <filename>%2</filename>.", device().deviceNode(), partition().deviceNode());
+            report->line() << xi18nc("@info:progress", "Could not open device <filename>%1</filename> to create new partition <filename>%2</filename>.", device().deviceNode(), partition().deviceNode());
+    } else if (device().type() == Device::LVM_Device) {
+        LvmDevice& dev = dynamic_cast<LvmDevice&>(device());
+        partition().setState(Partition::StateNone);
 
-        delete backendDevice;
-    } else
-        report->line() << xi18nc("@info/plain", "Could not open device <filename>%1</filename> to create new partition <filename>%2</filename>.", device().deviceNode(), partition().deviceNode());
+        QString partPath = partition().partitionPath();
+        QString lvname   = partPath.right(partPath.length() - partPath.lastIndexOf(QStringLiteral("/")) - 1);
+        rval = LvmDevice::createLV(*report, dev, partition(), lvname);
+    }
 
     jobFinished(*report, rval);
 
@@ -81,7 +91,7 @@ bool CreatePartitionJob::run(Report& parent)
 QString CreatePartitionJob::description() const
 {
     if (partition().number() > 0)
-        return xi18nc("@info/plain", "Create new partition <filename>%1</filename>", partition().deviceNode());
+        return xi18nc("@info:progress", "Create new partition <filename>%1</filename>", partition().deviceNode());
 
-    return xi18nc("@info/plain", "Create new partition on device <filename>%1</filename>", device().deviceNode());
+    return xi18nc("@info:progress", "Create new partition on device <filename>%1</filename>", device().deviceNode());
 }
