@@ -59,9 +59,9 @@ bool MoveFileSystemJob::run(Report& parent)
         CopyTargetDevice moveTarget(device(), newStart(), newStart() + partition().fileSystem().length());
 
         if (!moveSource.open())
-            report->line() << xi18nc("@info/plain", "Could not open file system on partition <filename>%1</filename> for moving.", partition().deviceNode());
+            report->line() << xi18nc("@info:progress", "Could not open file system on partition <filename>%1</filename> for moving.", partition().deviceNode());
         else if (!moveTarget.open())
-            report->line() << xi18nc("@info/plain", "Could not create target for moving file system on partition <filename>%1</filename>.", partition().deviceNode());
+            report->line() << xi18nc("@info:progress", "Could not create target for moving file system on partition <filename>%1</filename>.", partition().deviceNode());
         else {
             rval = copyBlocks(*report, moveTarget, moveSource);
 
@@ -70,9 +70,9 @@ bool MoveFileSystemJob::run(Report& parent)
                 partition().fileSystem().setFirstSector(newStart());
                 partition().fileSystem().setLastSector(newStart() + savedLength);
             } else if (!rollbackCopyBlocks(*report, moveTarget, moveSource))
-                report->line() << xi18nc("@info/plain", "Rollback for file system on partition <filename>%1</filename> failed.", partition().deviceNode());
+                report->line() << xi18nc("@info:progress", "Rollback for file system on partition <filename>%1</filename> failed.", partition().deviceNode());
 
-            report->line() << i18nc("@info/plain", "Closing device. This may take a few seconds.");
+            report->line() << xi18nc("@info:progress", "Closing device. This may take a few seconds.");
         }
     }
 
@@ -86,5 +86,5 @@ bool MoveFileSystemJob::run(Report& parent)
 
 QString MoveFileSystemJob::description() const
 {
-    return xi18nc("@info/plain", "Move the file system on partition <filename>%1</filename> to sector %2", partition().deviceNode(), newStart());
+    return xi18nc("@info:progress", "Move the file system on partition <filename>%1</filename> to sector %2", partition().deviceNode(), newStart());
 }
