@@ -38,7 +38,6 @@ class LibPartedPartitionTable;
 class LibPartedPartition;
 class OperationStack;
 
-class Device;
 class KPluginFactory;
 class QString;
 
@@ -61,10 +60,10 @@ private:
 public:
     void initFSSupport() override;
 
-    CoreBackendDevice* openDevice(const QString& device_node) override;
-    CoreBackendDevice* openDeviceExclusive(const QString& device_node) override;
+    CoreBackendDevice* openDevice(const QString& deviceNode) override;
+    CoreBackendDevice* openDeviceExclusive(const QString& deviceNode) override;
     bool closeDevice(CoreBackendDevice* core_device) override;
-    Device* scanDevice(const QString& device_node) override;
+    Device* scanDevice(const QString& deviceNode) override;
     QList<Device*> scanDevices(bool excludeReadOnly = false) override;
     FileSystem::Type detectFileSystem(const QString& partitionPath) override;
 
